@@ -1,6 +1,6 @@
 package Parse::Dia::SQL;
 
-# $Id: SQL.pm,v 1.47 2010/02/01 20:45:40 aff Exp $
+# $Id: SQL.pm,v 1.49 2010/04/08 19:22:35 aff Exp $
 
 =pod
 
@@ -43,7 +43,7 @@ See L<http://tedia2sql.tigris.org/usingtedia2sql.html>
 
 =item * Index options are supported.  Text is taken from the I<comments> field of the I<operation>, i.e. the index.  A database specific default value is used if the I<comments> field is left blank.  Consult the Output sub class' constructor.
 
-=item * Type mapping is supported as of version 0.13_01. Unlike I<tedia2sql> the type mapping is non-recursive.
+=item * Type mapping is supported. A type mapping is a user-defined column name replacement. Unlike I<tedia2sql> the type mapping is non-recursive.  Consult C<t/data/typemap.dia> for an example. 
 
 =back
 
@@ -51,8 +51,6 @@ See L<http://tedia2sql.tigris.org/usingtedia2sql.html>
 
 Parse::Dia::SQL has been tested with Dia versions 0.93 - 0.97.
 
-Dia version 0.97 changed the way associations were stored, and support for this has been added as of Parse::Dia::SQL version 0.11.
-
 Parse::Dia::SQL uses the XML C<version> tag information in the I<.dia> input file to determine how each XML construct is formatted.  Future versions of Dia may change the internal format, and XML C<version> tag is used to detect such changes.
 
 =head1 DATABASE SUPPORT
@@ -190,12 +188,13 @@ use Parse::Dia::SQL::Output::Sas;
 use Parse::Dia::SQL::Output::Sybase;
 use Parse::Dia::SQL::Output::SQLite3;
 
-our $VERSION = '0.13_02';
+our $VERSION = '0.14_01';
 
-my $UML_ASSOCIATION  = 'UML - Association';
-my $UML_SMALLPACKAGE = 'UML - SmallPackage';
-my $UML_CLASS        = 'UML - Class';
-my $UML_COMPONENT    = 'UML - Component';
+my $UML_ASSOCIATION     = 'UML - Association';
+my $UML_SMALLPACKAGE    = 'UML - SmallPackage';
+my $UML_CLASS           = 'UML - Class';
+my $UML_COMPONENT       = 'UML - Component';
+my $DATABASE_TABLE      = 'Database - Table';  # UNSUPPORTED !
 
 =head1 METHODS
 
@@ -481,6 +480,13 @@ sub _parse_smallpackages {
         my $nodeAttrVersion = $nodelist->item($i)->getAttribute('version');
         $self->{log}->debug("Node $i -- type=$nodeAttrType");
 
+        ########################################################################
+	# REMOVE THE BELOW 3 LINES IF SUPPORT FOR 'Database - Table' IS ADDED
+        if ( $nodeAttrType eq $DATABASE_TABLE ) {
+	    $self->{log}->logdie("Unsupported diagram type '$DATABASE_TABLE'. Use the '$UML_CLASS' instead.");
+	}
+        ########################################################################
+
         if ( $nodeAttrType eq $UML_SMALLPACKAGE ) {
 
           # Check that version is supported
